API docs for “spamfighter.core.log.LogEntry”

# Class s.c.l.LogEntry(object):

Part of spamfighter.core.log View Source View In Hierarchy

Объект отдельной записи в логе.

Объект должен быть сериализуемым (для передачи в рамках API), а также pickle'уемым (для хранения в storage).

Instance Variables | when | время и дата сообщения, UTC (type: `int` )
| message | само сообщение (type: `TransitMessage` )
| tags | тэги, привязанные к сообщению (type: `list(str)` )
| id | ID записи (type: `int` )

Method | __init__ | Конструктор.
Method | serialize | Сериализовать запись в логе.
Class Method | unserialize | Десериализовать сообщение.
Method | __repr__ | Undocumented
Method | __eq__ | Undocumented

def __init__(self, when, message, tags=None, id=None): (source)
Конструктор.

Parameters | when | дата/время записи в логе, UTC (type: `int` )
| message | само сообщение (type: `IMessage` или `ITaggedMessage` или `TransitMessage` )
| tags | тэги, привзяанные к сообщению (type: `list(str)` )

def serialize(self): (source)
Сериализовать запись в логе.

@classmethod
def unserialize(cls, serialized): (source)
Десериализовать сообщение.

Parameters | serialized | сериализованное представление сообщения (type: `dict` )

def __repr__(self): (source)
Undocumented
def __eq__(self, other): (source)
Undocumented